/* FreeRTOS includes. */
#include "FreeRTOS.h"
#include "task.h"

/* ST HAL. */
#include "stm32l4xx_hal.h"

/* Initialization related. */
#include "initialize.h"

#define INTRODUCE_SECOND_LED        0

/* The task which implements the application. */
static void prvApplicationTask( void * pvParams );
/*-----------------------------------------------------------*/

static void prvApplicationTask( void * pvParams )
{
    GPIO_InitTypeDef  gpio_init_structure;

    /* Silence compiler warnings about unused variables. */
    ( void ) pvParams;

    /* Configure the GPIO for LED2 (PB14). */
    gpio_init_structure.Pin   = GPIO_PIN_14;
    gpio_init_structure.Mode  = GPIO_MODE_OUTPUT_PP;
    gpio_init_structure.Pull  = GPIO_NOPULL;
    gpio_init_structure.Speed = GPIO_SPEED_FREQ_HIGH;

    HAL_GPIO_Init( GPIOB, &( gpio_init_structure ) );
    HAL_GPIO_WritePin( GPIOB, GPIO_PIN_14, GPIO_PIN_SET );

#if( INTRODUCE_SECOND_LED == 1 )
    /* Configure the GPIO for LED1 (PA5). */
    gpio_init_structure.Pin   = GPIO_PIN_5;

    HAL_GPIO_Init( GPIOA, &( gpio_init_structure ) );
    HAL_GPIO_WritePin( GPIOA, GPIO_PIN_5, GPIO_PIN_RESET );
#endif /* INTRODUCE_SECOND_LED */


    for( ; ; )
    {
        HAL_GPIO_TogglePin( GPIOB, GPIO_PIN_14 );

    #if( INTRODUCE_SECOND_LED == 1 )
        HAL_GPIO_TogglePin( GPIOA, GPIO_PIN_5 );
    #endif /* INTRODUCE_SECOND_LED */

        vTaskDelay( pdMS_TO_TICKS( 1000 ) );
    }
}
/*-----------------------------------------------------------*/

void vStartApplication( void )
{
    /* Initialize Application. */
    InitializeHardware();

    /* Create the application task. */
    xTaskCreate( prvApplicationTask,
                 "App",
                 256,
                 NULL,
                 tskIDLE_PRIORITY,
                 NULL );

    /* Start the scheduler. */
    vTaskStartScheduler();
}
/*-----------------------------------------------------------*/
