/* FreeRTOS includes. */
#include "FreeRTOS.h"
#include "task.h"

/* Function Ids. */
#include "freertos_function_ids.h"

/* Component header. */
#include "component_header.h"

/* Dynamic loader. */
#include "dynamic_loader.h"

extern uint32_t _sidata[];
extern uint32_t _sdata[];
extern uint32_t _edata[];
extern uint32_t _sbss[];
extern uint32_t _ebss[];

extern void vPortSVCHandler( void );
extern void xPortPendSVHandler( void );
extern void xPortSysTickHandler( void );
/*-----------------------------------------------------------*/

function_definition_t exported_functions[] __attribute__ ((section(".exported_functions"))) =
{
    { xTaskCreateID,            ( uint32_t ) xTaskCreate            },
    { vTaskStartSchedulerID,    ( uint32_t ) vTaskStartScheduler    },
    { vTaskDelayID,             ( uint32_t ) vTaskDelay             },
    { 0,                        0                                   },
};
/*-----------------------------------------------------------*/

isr_definition_t required_isrs[] __attribute__ ((section(".required_isrs"))) =
{
    { SVC_Handler_ID,       ( uint32_t ) vPortSVCHandler     },
    { PendSV_Handler_ID,    ( uint32_t ) xPortPendSVHandler  },
    { SysTick_Handler_ID,   ( uint32_t ) xPortSysTickHandler },
    { 0,                    0                                },
};
/*-----------------------------------------------------------*/

component_header_t header __attribute__ ((section(".component_header"))) = 
{
    .component_id           = FREERTOS_ID,
    .data_rom_start         = ( uint32_t ) _sidata,
    .data_ram_start         = ( uint32_t ) _sdata,
    .data_ram_end           = ( uint32_t ) _edata,
    .bss_ram_start          = ( uint32_t ) _sbss,
    .bss_ram_end            = ( uint32_t ) _ebss,
    .entry_point            = 0,
    .function_table_start   = ( uint32_t ) exported_functions,
    .isr_table_start        = ( uint32_t ) required_isrs,
};
/*-----------------------------------------------------------*/
