#ifndef COMPONENT_HEADER_H_
#define COMPONENT_HEADER_H_

/* Standard includes. */
#include <stdint.h>

/* Header that must be placed at the beginning of each component. */
typedef struct component_header
{
    uint32_t component_id;
    uint32_t data_rom_start;
    uint32_t data_ram_start;
    uint32_t data_ram_end;
    uint32_t bss_ram_start;
    uint32_t bss_ram_end;
    uint32_t entry_point;
    uint32_t function_table_start;
    uint32_t isr_table_start;
} component_header_t;

/* function_table_start in the component_header_t must be an array of
 * function_definition_t terminated by an entry containing 0 for both
 * function_id and function_address. */
typedef struct function_definition
{
    uint32_t function_id;
    uint32_t function_address;
} function_definition_t;

/* isr_table_start in the component_header_t must be an array of
 * isr_definition_t terminated by an entry containing 0 for both isr_id and
 * isr_address. */
typedef struct isr_definition
{
    uint32_t isr_id;
    uint32_t isr_address;
} isr_definition_t;

#endif /* COMPONENT_HEADER_H_ */
