#ifndef DYNAMIC_LOADER_H_
#define DYNAMIC_LOADER_H_

/* Standard includes. */
#include <stdint.h>

/* IDs (Indexes) of various ISRs in the vector table. */
#define Reset_Handler_ID                   1
#define NMI_Handler_ID                     2
#define HardFault_Handler_ID               3
#define MemManage_Handler_ID               4
#define BusFault_Handler_ID                5
#define UsageFault_Handler_ID              6
#define SVC_Handler_ID                     11
#define DebugMon_Handler_ID                12
#define PendSV_Handler_ID                  14
#define SysTick_Handler_ID                 15
#define WWDG_IRQHandler_ID                 16
#define PVD_PVM_IRQHandler_ID              17
#define TAMP_STAMP_IRQHandler_ID           18
#define RTC_WKUP_IRQHandler_ID             19
#define FLASH_IRQHandler_ID                20
#define RCC_IRQHandler_ID                  21
#define EXTI0_IRQHandler_ID                22
#define EXTI1_IRQHandler_ID                23
#define EXTI2_IRQHandler_ID                24
#define EXTI3_IRQHandler_ID                25
#define EXTI4_IRQHandler_ID                26
#define DMA1_Channel1_IRQHandler_ID        27
#define DMA1_Channel2_IRQHandler_ID        28
#define DMA1_Channel3_IRQHandler_ID        29
#define DMA1_Channel4_IRQHandler_ID        30
#define DMA1_Channel5_IRQHandler_ID        31
#define DMA1_Channel6_IRQHandler_ID        32
#define DMA1_Channel7_IRQHandler_ID        33
#define ADC1_2_IRQHandler_ID               34
#define CAN1_TX_IRQHandler_ID              35
#define CAN1_RX0_IRQHandler_ID             36
#define CAN1_RX1_IRQHandler_ID             37
#define CAN1_SCE_IRQHandler_ID             38
#define EXTI9_5_IRQHandler_ID              39
#define TIM1_BRK_TIM15_IRQHandler_ID       40
#define TIM1_UP_TIM16_IRQHandler_ID        41
#define TIM1_TRG_COM_TIM17_IRQHandler_ID   42
#define TIM1_CC_IRQHandler_ID              43
#define TIM2_IRQHandler_ID                 44
#define TIM3_IRQHandler_ID                 45
#define TIM4_IRQHandler_ID                 46
#define I2C1_EV_IRQHandler_ID              47
#define I2C1_ER_IRQHandler_ID              48
#define I2C2_EV_IRQHandler_ID              49
#define I2C2_ER_IRQHandler_ID              50
#define SPI1_IRQHandler_ID                 51
#define SPI2_IRQHandler_ID                 52
#define USART1_IRQHandler_ID               53
#define USART2_IRQHandler_ID               54
#define USART3_IRQHandler_ID               55
#define EXTI15_10_IRQHandler_ID            56
#define RTC_Alarm_IRQHandler_ID            57
#define DFSDM1_FLT3_IRQHandler_ID          58
#define TIM8_BRK_IRQHandler_ID             59
#define TIM8_UP_IRQHandler_ID              60
#define TIM8_TRG_COM_IRQHandler_ID         61
#define TIM8_CC_IRQHandler_ID              62
#define ADC3_IRQHandler_ID                 63
#define FMC_IRQHandler_ID                  64
#define SDMMC1_IRQHandler_ID               65
#define TIM5_IRQHandler_ID                 66
#define SPI3_IRQHandler_ID                 67
#define UART4_IRQHandler_ID                68
#define UART5_IRQHandler_ID                69
#define TIM6_DAC_IRQHandler_ID             70
#define TIM7_IRQHandler_ID                 71
#define DMA2_Channel1_IRQHandler_ID        72
#define DMA2_Channel2_IRQHandler_ID        73
#define DMA2_Channel3_IRQHandler_ID        74
#define DMA2_Channel4_IRQHandler_ID        75
#define DMA2_Channel5_IRQHandler_ID        76
#define DFSDM1_FLT0_IRQHandler_ID          77
#define DFSDM1_FLT1_IRQHandler_ID          78
#define DFSDM1_FLT2_IRQHandler_ID          79
#define COMP_IRQHandler_ID                 80
#define LPTIM1_IRQHandler_ID               81
#define LPTIM2_IRQHandler_ID               82
#define OTG_FS_IRQHandler_ID               83
#define DMA2_Channel6_IRQHandler_ID        84
#define DMA2_Channel7_IRQHandler_ID        85
#define LPUART1_IRQHandler_ID              86
#define QUADSPI_IRQHandler_ID              87
#define I2C3_EV_IRQHandler_ID              88
#define I2C3_ER_IRQHandler_ID              89
#define SAI1_IRQHandler_ID                 90
#define SAI2_IRQHandler_ID                 91
#define SWPMI1_IRQHandler_ID               92
#define TSC_IRQHandler_ID                  93
#define RNG_IRQHandler_ID                  96
#define FPU_IRQHandler_ID                  97

/* IDs assigned to various components. */
#define BSP_ID                             0
#define FREERTOS_ID                        1
#define APPLICATION_ID                     2

/* Function type of get_proc_address. */
typedef uint32_t ( * get_proc_address_t )( uint32_t component_id, uint32_t function_id );

/* Used by components to get the address of a function. */
#define GET_PROC_ADDRESS( component_id, function_id ) \
    ( ( get_proc_address_t )( 0x08000401 ) )( component_id, function_id )

#endif /* DYNAMIC_LOADER_H_ */
