/* Standard includes. */
#include <string.h>

/* Interface include. */
#include "isr_db.h"

/* VTOR register address. */
#define SCB_VTOR_REG_ADDRESS        ( 0xE000ED08UL )

/* Size of vector table. */
#define VECTOR_TABLE_SIZE           98 /* 98 words. */

static uint32_t ram_vector_table[ VECTOR_TABLE_SIZE ] __attribute__ ((section(".ram_vector_table")));

void initialize_isr_db( void )
{
    extern uint32_t g_pfnVectors[];

    /* Copy the vector table from Flash to RAM. */
    memcpy( ram_vector_table, g_pfnVectors, VECTOR_TABLE_SIZE * sizeof( uint32_t ) );
}
/*-----------------------------------------------------------*/

void install_isr( uint32_t isr_id, uint32_t isr_address )
{
    if( isr_id < VECTOR_TABLE_SIZE )
    {
        ram_vector_table[ isr_id ] = isr_address;
    }
}
/*-----------------------------------------------------------*/

void apply_isr_db( void )
{
    /* Relocate vector table. */
    *( ( volatile uint32_t * ) SCB_VTOR_REG_ADDRESS ) = ( uint32_t ) ram_vector_table;
}
/*-----------------------------------------------------------*/
